@@ -61,17 +61,18 @@ def load_from_sql(session, table):
     """Constructs from database table
 
     :param sqlalchemy.orm.Session session: SQLAlchemy session object
-    :param sqlalchemy.ext.declarative table: SQLAlchemy database table
+    :param sqlalchemy orm table table: SQLAlchemy database table
     :returns: :class:`Sheet`
     """
     array = []
     objects = session.query(table).all()
-    column_names = [column.name for column in objects[0].__table__.columns]
+    column_names = sorted([column for column in objects[0].__dict__
+                           if column != '_sa_instance_state'])
     array.append(column_names)
     for o in objects:
         new_array = []
         for column in column_names:
-            value = getattr(o,column)
+            value = getattr(o, column)
             if isinstance(value, (datetime.date, datetime.time)):
                 value = value.isoformat()
             new_array.append(value)
@@ -80,7 +81,7 @@ def load_from_sql(session, table):
 
 
 class Sheet(NominableSheet):
-    """Two dimensional data container for filtering, formatting and custom iteration
+    """Two dimensional data container for filtering, formatting and iteration
 
     :class:`Sheet` is a container for a two dimensional array, where individual
     cell can be any Python types. Other than numbers, value of thsee
@@ -97,21 +98,21 @@ class Sheet(NominableSheet):
     Filtering functions are used to reduce the information contained in the
     array.
     """
-    def save_as(self, filename):
+    def save_as(self, filename, **keywords):
         """Save the content to a named file"""
         from ..writers import Writer
-        w = Writer(filename)
+        w = Writer(filename, sheet_name=self.name, **keywords)
         w.write_reader(self)
         w.close()
 
-    def save_to_memory(self, file_type, stream):
+    def save_to_memory(self, file_type, stream, **keywords):
         """Save the content to memory
 
         :param str file_type: any value of 'csv', 'tsv', 'csvz',
         'tsvz', 'xls', 'xlsm', 'xslm', 'ods'
         :param iostream stream: the memory stream to be written to
         """
-        self.save_as((file_type, stream))
+        self.save_as((file_type, stream), **keywords)
 
 
 def Reader(file=None, sheetname=None, **keywords):
