@@ -7,9 +7,8 @@
     :copyright: (c) 2014 by C. W.
     :license: GPL v3
 """
-import six
-from .sheets import IndexSheet, Sheet
-from ._compact import OrderedDict
+from .sheets import NominableSheet, Sheet
+from ._compact import OrderedDict, PY2
 
 
 def to_array(o):
@@ -47,7 +46,7 @@ def to_records(reader, custom_headers=None):
     database operations.
     """
     ret = []
-    if isinstance(reader, IndexSheet) is False:
+    if isinstance(reader, NominableSheet) is False:
         raise NotImplementedError
     if len(reader.rownames) > 0:
         if custom_headers:
@@ -108,7 +107,7 @@ def dict_to_array(the_dict, with_keys=True):
             "Column 2": [5, 6, 7, 8],
             "Column 3": [9, 10, 11, 12, 13],
         }
-    
+
     The output will be::
 
         [
@@ -119,13 +118,13 @@ def dict_to_array(the_dict, with_keys=True):
             ['', 8, 12],
             ['', '', 13]
         ]
-    
+
     :param dict the_dict: the dictionary to be converted.
     :param bool with_keys: to write the keys as the first row or not
     """
     content = []
     keys = the_dict.keys()
-    if six.PY3:
+    if not PY2:
         keys = list(keys)
     if not isinstance(the_dict, OrderedDict):
         keys = sorted(keys)
@@ -147,4 +146,3 @@ def dict_to_array(the_dict, with_keys=True):
                 row_data.append('')
         content.append(row_data)
     return content
-
